def get_classes():
    
    from Navigator import Navigator
    from GenericThumbnailer import GenericThumbnailer
    return [Navigator,
            GenericThumbnailer]

